@@ -39,31 +39,31 @@ interface b {
 interface c {
     c: any;
 }
-declare type T1 = ([a, b, c]);
-declare type F1 = ([a, b, c]: [any, any, any]) => void;
-declare type T2 = ({
+type T1 = ([a, b, c]);
+type F1 = ([a, b, c]: [any, any, any]) => void;
+type T2 = ({
     a: any;
 });
-declare type F2 = ({ a }: {
+type F2 = ({ a }: {
     a: any;
 }) => void;
-declare type T3 = ([{
+type T3 = ([{
     a: b;
 }, {
     b: a;
 }]);
-declare type F3 = ([{ a }, { b }]: [{
+type F3 = ([{ a }, { b }]: [{
     a: any;
 }, {
     b: any;
 }]) => void;
-declare type T4 = ([{
+type T4 = ([{
     a: [b, c];
 }]);
-declare type F4 = ([{ a: [b, c] }]: [{
+type F4 = ([{ a: [b, c] }]: [{
     a: [any, any];
 }]) => void;
-declare type C1 = new ([{ a: [b, c] }]: [{
+type C1 = new ([{ a: [b, c] }]: [{
     a: [any, any];
 }]) => void;
 declare var v1: ([a, b, c]: [any, any, any]) => string;
