@@ -29,6 +29,11 @@ const g3 = g(GenericNumberOrString);
 g3.give(1);
 g3.give('1');
 
+// repro from #35636
+class C<T> {}
+const g4 = g(C);
+
+
 //// [inferringReturnTypeFromConstructSignatureGeneric.js]
 var GenericObject = /** @class */ (function () {
     function GenericObject() {
@@ -64,3 +69,10 @@ g2.give(1);
 var g3 = g(GenericNumberOrString);
 g3.give(1);
 g3.give('1');
+// repro from #35636
+var C = /** @class */ (function () {
+    function C() {
+    }
+    return C;
+}());
+var g4 = g(C);
