@@ -43,21 +43,21 @@ Shape signatures in builder refreshed for::
 /a/lib/lib.d.ts (used version)
 /home/username/project/app/file.ts (used version)
 
-WatchedFiles::
-/home/username/project/tsconfig.json:
-  {"fileName":"/home/username/project/tsconfig.json","pollingInterval":250}
-/home/username/project/app/file.ts:
-  {"fileName":"/home/username/project/app/file.ts","pollingInterval":250}
-/a/lib/lib.d.ts:
-  {"fileName":"/a/lib/lib.d.ts","pollingInterval":250}
+PolledWatches::
 /home/username/project/node_modules/@types:
-  {"fileName":"/home/username/project/node_modules/@types","pollingInterval":500}
+  {"pollingInterval":500}
 
 FsWatches::
+/home/username/project/tsconfig.json:
+  {}
+/home/username/project/app/file.ts:
+  {}
+/a/lib/lib.d.ts:
+  {}
 
 FsWatchesRecursive::
 /home/username/project/app:
-  {"directoryName":"/home/username/project/app"}
+  {}
 
 exitCode:: ExitStatus.undefined
 
@@ -96,21 +96,21 @@ Semantic diagnostics in builder refreshed for::
 Shape signatures in builder refreshed for::
 /home/username/project/app/file.ts (computed .d.ts)
 
-WatchedFiles::
-/home/username/project/tsconfig.json:
-  {"fileName":"/home/username/project/tsconfig.json","pollingInterval":250}
-/home/username/project/app/file.ts:
-  {"fileName":"/home/username/project/app/file.ts","pollingInterval":250}
-/a/lib/lib.d.ts:
-  {"fileName":"/a/lib/lib.d.ts","pollingInterval":250}
+PolledWatches::
 /home/username/project/node_modules/@types:
-  {"fileName":"/home/username/project/node_modules/@types","pollingInterval":500}
+  {"pollingInterval":500}
 
 FsWatches::
+/home/username/project/tsconfig.json:
+  {}
+/home/username/project/app/file.ts:
+  {}
+/a/lib/lib.d.ts:
+  {}
 
 FsWatchesRecursive::
 /home/username/project/app:
-  {"directoryName":"/home/username/project/app"}
+  {}
 
 exitCode:: ExitStatus.undefined
 
