@@ -27,6 +27,10 @@ Output::
 >> Screen clear
 [[90m12:00:17 AM[0m] Starting compilation in watch mode...
 
+sysLog:: /a/b/tsconfig.json:: Changing to watchFile
+sysLog:: /a/b/commonFile1.ts:: Changing to watchFile
+sysLog:: /a/b/commonFile2.ts:: Changing to watchFile
+sysLog:: /a/lib/lib.d.ts:: Changing to watchFile
 [[90m12:00:22 AM[0m] Found 0 errors. Watching for file changes.
 
 sysLog:: /a/b:: Changing to watchFile
@@ -50,19 +54,19 @@ Shape signatures in builder refreshed for::
 /a/b/commonfile1.ts (used version)
 /a/b/commonfile2.ts (used version)
 
-WatchedFiles::
+PolledWatches::
 /a/b/tsconfig.json:
-  {"fileName":"/a/b/tsconfig.json","pollingInterval":250}
+  {"pollingInterval":2000}
 /a/b/commonfile1.ts:
-  {"fileName":"/a/b/commonFile1.ts","pollingInterval":250}
+  {"pollingInterval":250}
 /a/b/commonfile2.ts:
-  {"fileName":"/a/b/commonFile2.ts","pollingInterval":250}
+  {"pollingInterval":250}
 /a/lib/lib.d.ts:
-  {"fileName":"/a/lib/lib.d.ts","pollingInterval":250}
+  {"pollingInterval":250}
 /a/b/node_modules/@types:
-  {"fileName":"/a/b/node_modules/@types","pollingInterval":500}
+  {"pollingInterval":500}
 /a/b:
-  {"fileName":"/a/b","pollingInterval":500}
+  {"pollingInterval":500}
 
 FsWatches::
 
