@@ -42,22 +42,12 @@ verify.completions({
     includes: [
         {
             name: "hint",
-            sortText: completion.SortText.LocationPriority,
-            replacementSpan: {
-                fileName: "",
-                pos: 0,
-                end: 0,
-            },
+            sortText: completion.SortText.ClassMemberSnippets,
             insertText: "protected hint(): string {\n}",
         },
         {
             name: "refuse",
-            sortText: completion.SortText.LocationPriority,
-            replacementSpan: {
-                fileName: "",
-                pos: 0,
-                end: 0,
-            },
+            sortText: completion.SortText.ClassMemberSnippets,
             insertText: "public refuse(): string {\n}",
         }
     ],
